@@ -35,6 +35,8 @@ DBUS_INTERFACE_XML = '''
     </method>
     <method name='NewNoteBlank'>
     </method>
+    <method name='ReloadNotesFromFile'>
+    </method>
     <signal name='NotesChanged'>
     </signal>
   </interface>
@@ -828,13 +830,17 @@ class Application(Gtk.Application):
             self.activate_notes(0)
 
         elif method_name == 'NewNote':
-            x, y = self.find_note_location(40, 40)
+            x, y, direction = self.get_direction()
+            x, y = self.find_note_location(x, y, direction)
 
             self.add_note({'text': params.unpack()[0], 'x': x, 'y': y})
 
         elif method_name == 'NewNoteBlank':
             self.new_note()
 
+        elif method_name == 'ReloadNotesFromFile':
+            self.reload_notes_from_file()
+
     def first_run(self):
         gnote_dir = os.path.join(GLib.get_user_data_dir(), 'gnote')
 
@@ -997,10 +1003,14 @@ class Application(Gtk.Application):
 
         return x, y
 
-    def new_note(self, button=None, parent=None):
-        workarea_rect = Gdk.Monitor.get_workarea(
-            Gdk.Display.get_primary_monitor(Gdk.Display.get_default())
-        )
+    def get_direction(self, parent=None):
+        monitor = Gdk.Display.get_primary_monitor(Gdk.Display.get_default())
+        if monitor == None:
+            # if user has no monitor configured, or uses Wayland, for now guess
+            # monitor 0 (better than a crash)
+            monitor = Gdk.Display.get_monitor(Gdk.Display.get_default(),0)
+
+        workarea_rect = Gdk.Monitor.get_workarea(monitor)
         direction = [1, 1]
         if parent:
             if parent.x > (workarea_rect.width / 2):
@@ -1029,6 +1039,11 @@ class Application(Gtk.Application):
                 y = workarea_rect.height / 2 - self.settings.get_uint('default-height') / 2
             else:
                 y = 20
+        
+        return (x, y, direction)
+
+    def new_note(self, button=None, parent=None):
+        x, y, direction = self.get_direction(parent)
 
         x, y = self.find_note_location(x, y, direction)
 
@@ -1066,6 +1081,10 @@ class Application(Gtk.Application):
         for note_info in self.file_handler.get_note_list(self.note_group):
             self.generate_note(note_info)
 
+    def reload_notes_from_file(self):
+        self.file_handler.load_notes()
+        self.load_notes();
+
     def duplicate_note(self, new_note):
         new_note_info = new_note.get_info()
         new_note_info['x'] += 50
@@ -1157,7 +1176,7 @@ class Application(Gtk.Application):
         dlg.set_program_name(_("Notes"))
         dlg.set_comments(_("Take notes and stay organized"))
         try:
-            h = open('/usr/share/licenses/spdx/GPL-2.0-only.txt', encoding="utf-8")
+            h = open('/usr/share/common-licenses/GPL', encoding="utf-8")
             s = h.readlines()
             gpl = ""
             for line in s:
@@ -1167,7 +1186,7 @@ class Application(Gtk.Application):
         except Exception as e:
             print (e)
 
-        dlg.set_version("1.24")
+        dlg.set_version("1.26")
         dlg.set_icon_name("sticky")
         dlg.set_logo_icon_name("sticky")
         dlg.set_website("https://www.github.com/linuxmint/sticky")
